pub(crate) const SHUTDOWN: &str = "/admin/shutdown";
pub(crate) const APP: &str = "/api/v1/app";
pub(crate) const APP_METADATA: &str = "/api/v1/app/metadata";
pub(crate) const BUILD: &str = "/api/v1/build";
pub(crate) const BUILD_CACHE: &str = "/api/v1/build-cache";
pub(crate) const BUILD_METADATA: &str = "/api/v1/build/metadata";
pub(crate) const BUILD_SNAPSHOT: &str = "/api/v1/build/snapshot";
pub(crate) const BUILD_LOG: &str = "/api/v1/build/log";
pub(crate) const CANCEL_BUILD: &str = "/api/v1/build/cancel";
pub(crate) const MANIFEST: &str = "/api/v1/manifest";
pub(crate) const MANIFEST_METADATA: &str = "/api/v1/manifest/metadata";
pub(crate) const MANIFEST_SNAPSHOT: &str = "/api/v1/manifest/snapshot";
pub(crate) const CATALOG_SCHEMA: &str = "/api/v1/catalog-schema";
pub(crate) const CATALOG_SCHEMA_METADATA: &str = "/api/v1/catalog-schema/metadata";
pub(crate) const CATALOG_SCHEMA_SNAPSHOT: &str = "/api/v1/catalog-schema/snapshot";
pub(crate) const CATALOGS: &str = "/api/v1/catalogs";
pub(crate) const CATALOGS_METADATA: &str = "/api/v1/catalogs/metadata";
pub(crate) const CATALOGS_SNAPSHOT: &str = "/api/v1/catalogs/snapshot";
pub(crate) const NODE_STATE: &str = "/api/v1/node";
pub(crate) const SCAN_BUILD: &str = "/api/v1/build/scan";
pub(crate) const SCAN_BUILD_CACHE: &str = "/api/v1/build-cache/scan";
pub(crate) const ACTIVATE_NODE: &str = "/api/v1/node/activate";
pub(crate) const DEACTIVATE_NODE: &str = "/api/v1/node/deactivate";
pub(crate) const SHUTDOWN_NODE: &str = "/api/v1/node/shutdown";
pub(crate) const NAMESPACE: &str = "/api/v1/namespace";
pub(crate) const PROJECT: &str = "/api/v1/project";

pub(crate) const DISPLAY_BUILD_STATUS_WIDTH: usize = 12;
pub(crate) const DISPLAY_ID_WIDTH: usize = 12;
pub(crate) const DISPLAY_COUNT_WIDTH: usize = 12;
pub(crate) const DISPLAY_NAMESPACE_WIDTH: usize = 12;
pub(crate) const DISPLAY_NODE_STATUS_WIDTH: usize = 12;
pub(crate) const DISPLAY_NODE_ROLE_WIDTH: usize = 12;
pub(crate) const DISPLAY_NODE_ARCH_WIDTH: usize = 12;
pub(crate) const DISPLAY_NODE_OS_WIDTH: usize = 12;
pub(crate) const DISPLAY_SIZE_WIDTH: usize = 12;
pub(crate) const DISPLAY_VERSION_WIDTH: usize = 12;
pub(crate) const DISPLAY_ADDRESS_WIDTH: usize = 16;
pub(crate) const DISPLAY_BUILD_TARGET_PLATFORM_WIDTH: usize = 28;
pub(crate) const DISPLAY_TIMESTAMP_WIDTH: usize = 32;
pub(crate) const DISPLAY_MESSAGE_WIDTH: usize = 36;
